@@ -53,7 +53,7 @@ def unregister(func):
     func = function to be unregistered
     """
     if hasattr(atexit, "unregister"):
-        atexit.unregister(func):
+        atexit.unregister(func)
     else:
         handler_entries = [e for e in _exithandlers if e[0] == func]
         for e in handler_entries:
